@@ -4,15 +4,15 @@
 #' 
 #' @description Calculates confidence intervals for pseudo maximum likelihood estimator using jackknife procedure
 #' 
-#' @usage JackPML(ysA, ysB, pi_A, pi_B, domains_A, domains_B, N_A, N_B, conf_level, 
+#' @usage JackPML(ysA, ysB, piA, piB, domainsA, domainsB, N_A, N_B, conf_level, 
 #' sdA = "srs", sdB = "srs", strA = NULL, strB = NULL, clusA = NULL, clusB = NULL,  
-#' NhA = NULL, NhB = NULL, NclushA = NULL, NclushB = NULL, fcpA = FALSE, fcpB = FALSE)
-#' @param ysA A numeric vector of length \eqn{n_A} or a numeric matrix or data frame of dimensions \eqn{n_A} x \eqn{c} containing information about variable of interest from \eqn{s_A}.
-#' @param ysB A numeric vector of length \eqn{n_B} or a numeric matrix or data frame of dimensions \eqn{n_B} x \eqn{c} containing information about variable of interest from \eqn{s_B}.
-#' @param pi_A A numeric vector of length \eqn{n_A} or a square numeric matrix of dimension \eqn{n_A} containing first order or first and second order inclusion probabilities for units included in \eqn{s_A}.
-#' @param pi_B A numeric vector of length \eqn{n_B} or a square numeric matrix of dimension \eqn{n_B} containing first order or first and second order inclusion probabilities for units included in \eqn{s_B}.
-#' @param domains_A A character vector of size \eqn{n_A} indicating the domain each unit from \eqn{s_A} belongs to. Possible values are "a" and "ab".
-#' @param domains_B A character vector of size \eqn{n_B} indicating the domain each unit from \eqn{s_B} belongs to. Possible values are "b" and "ba".
+#' fcpA = FALSE, fcpB = FALSE)
+#' @param ysA A numeric vector of length \eqn{nA} or a numeric matrix or data frame of dimensions \eqn{nA} x \eqn{c} containing information about variable of interest from \eqn{s_A}.
+#' @param ysB A numeric vector of length \eqn{nB} or a numeric matrix or data frame of dimensions \eqn{nB} x \eqn{c} containing information about variable of interest from \eqn{s_B}.
+#' @param piA A numeric vector of length \eqn{nA} or a square numeric matrix of dimension \eqn{nA} containing first order or first and second order inclusion probabilities for units included in \eqn{s_A}.
+#' @param piB A numeric vector of length \eqn{nB} or a square numeric matrix of dimension \eqn{nB} containing first order or first and second order inclusion probabilities for units included in \eqn{s_B}.
+#' @param domainsA A character vector of size \eqn{nA} indicating the domain each unit from \eqn{s_A} belongs to. Possible values are "a" and "ab".
+#' @param domainsB A character vector of size \eqn{nB} indicating the domain each unit from \eqn{s_B} belongs to. Possible values are "b" and "ba".
 #' @param N_A A numeric value indicating the size of frame A
 #' @param N_B A numeric value indicating the size of frame B
 #' @param conf_level A numeric value indicating the confidence level for the confidence intervals.
@@ -22,10 +22,6 @@
 #' @param strB (Optional) A numeric vector indicating the stratum each unit in frame B belongs to, if a stratified sampling or a stratified cluster sampling has been considered in frame B.
 #' @param clusA (Optional) A numeric vector indicating the cluster each unit in frame A belongs to, if a cluster sampling or a stratified cluster sampling has been considered in frame A.
 #' @param clusB (Optional) A numeric vector indicating the cluster each unit in frame B belongs to, if a cluster sampling or a stratified cluster sampling has been considered in frame B.
-#' @param NhA (Optional) A numeric vector indicating the population size in each stratum of frame A. This is only needed when \code{sdA = "str"} and \code{fcpA = TRUE}.
-#' @param NhB (Optional) A numeric vector indicating the population size in each stratum of frame B. This is only needed when \code{sdB = "str"} and \code{fcpB = TRUE}.
-#' @param NclushA (Optional) A numeric vector indicating the population number of clusters in each stratum of frame A. This is only needed when \code{sdA = "strclu"} and \code{fcpA = TRUE}.
-#' @param NclushB (Optional) A numeric vector indicating the population number of clusters in each stratum of frame B. This is only needed when \code{sdB = "strclu"} and \code{fcpB = TRUE}.
 #' @param fcpA (Optional) A logic value indicating if a finite population correction factor should be considered in frame A. Default is FALSE.
 #' @param fcpB (Optional) A logic value indicating if a finite population correction factor should be considered in frame B. Default is FALSE. 
 #' @details Let suppose a non stratified sampling design in frame A and a stratified sampling design in frame B where frame has been divided into L strata and a sample of size \eqn{n_{Bl}} from the \eqn{N_{Bl}} composing the l-th stratum is selected
@@ -34,7 +30,7 @@
 #' with \eqn{\hat{Y}_c^A(i)} the value of estimator \eqn{\hat{Y}_c} after dropping \eqn{i-th} unit from \code{ysA} and \eqn{\overline{Y}_{c}^{A}} the mean of values \eqn{\hat{Y}_c^A(i)}.
 #' Similarly, \eqn{\hat{Y}_c^B(lj)} is the value taken by \eqn{\hat{Y}_c} after dropping j-th unit of l-th from sample \code{ysB} and \eqn{\overline{Y}_{c}^{Bl}} is the mean of values \eqn{\hat{Y}_c^B(lj)}.
 #' If needed, a finite population correction factor can be included in frames by replacing \eqn{\hat{Y}_{c}^{A}(i)} or \eqn{\hat{Y}_{c}^{B}(lj)} with \eqn{\hat{Y}_{c}^{A*}(i)= \hat{Y}_{c}+\sqrt{1-\overline{\pi}_A} (\hat{Y}_{c}^{A}(i) -\hat{Y}_{c})} or
-#' \eqn{\hat{Y}_{c}^{B*}(lj)= \hat{Y}_{c}+\sqrt{1-\overline{\pi}_B} (\hat{Y}_{c}^{B}(lj) -\hat{Y}_{c})}, where \eqn{\overline{\pi}_A = \sum_{i \in s_A}\pi_{iA}/n_A} and \eqn{\overline{\pi}_B = \sum_{j \in s_B}\pi_{jB}/n_B}
+#' \eqn{\hat{Y}_{c}^{B*}(lj)= \hat{Y}_{c}+\sqrt{1-\overline{\pi}_B} (\hat{Y}_{c}^{B}(lj) -\hat{Y}_{c})}, where \eqn{\overline{\pi}_A = \sum_{i \in s_A}\pi_{iA}/nA} and \eqn{\overline{\pi}_B = \sum_{j \in s_B}\pi_{jB}/nB}
 #' A confidence interval for any parameter of interest, \eqn{Y} can be calculated, then, using the pivotal method.
 #' @return A numeric matrix containing estimations of population total and population mean and their corresponding confidence intervals obtained through jackknife method.
 #' @references Wolter, K. M. (2007)
@@ -56,27 +52,38 @@
 #' #population correction factor is considered in both frames.
 #' JackPML(DatA$Lei, DatB$Lei, DatA$ProbA, DatB$ProbB, DatA$Domain, 
 #' DatB$Domain, 1735, 1191, 0.95, "str", "srs", strA = DatA$Stratum,
-#' NhA = c(727, 375, 113, 186, 115, 219), fcpA = TRUE, fcpB = TRUE)
+#' fcpA = TRUE, fcpB = TRUE)
 #' @export
-JackPML = function (ysA, ysB, pi_A, pi_B, domains_A, domains_B, N_A, N_B, conf_level, sdA = "srs", sdB = "srs", strA = NULL, strB = NULL, clusA = NULL, clusB = NULL, NhA = NULL, NhB = NULL, NclushA = NULL, NclushB = NULL, fcpA = FALSE, fcpB = FALSE){
+JackPML = function (ysA, ysB, piA, piB, domainsA, domainsB, N_A, N_B, conf_level, sdA = "srs", sdB = "srs", strA = NULL, strB = NULL, clusA = NULL, clusB = NULL, fcpA = FALSE, fcpB = FALSE){
 
 	cnames <- names(ysA)
 
 	ysA <- as.matrix(ysA)
 	ysB <- as.matrix(ysB)
-	pi_A <- as.matrix(pi_A)
-	pi_B <- as.matrix(pi_B)
+	piA <- as.matrix(piA)
+	piB <- as.matrix(piB)
 
 	c <- ncol(ysA)
 	results <- matrix(NA, nrow = 6, ncol = c)
 	rownames(results) <- c("Total", "Jack Upper End", "Jack Lower End", "Mean", "Jack Upper End", "Jack Lower End")
 	colnames(results) <- cnames
 
-	estimation <- PML(ysA, ysB, pi_A, pi_B, domains_A, domains_B, N_A, N_B)
+	estimation <- PML(ysA, ysB, piA, piB, domainsA, domainsB, N_A, N_B)
 	size_estimation <- estimation[[2]][1,1] / estimation[[2]][2,1]
 
+	if (!is.null(dim(drop(piA))))
+		pikA <- diag(piA)
+	else
+		pikA <- piA
+
+	if (!is.null(dim(drop(piB))))
+		pikB <- diag(piB)
+	else
+		pikB <- piB
+
 	if (sdA == "str"){
 
+		strataA <- unique(strA)
 		nhA <- table(strA)
 		nstrataA <- length(nhA)
 		YcstrataA <- matrix(0, nstrataA, c)
@@ -89,20 +96,20 @@ JackPML = function (ysA, ysB, pi_A, pi_B, domains_A, domains_B, N_A, N_B, conf_l
 			YcA <- matrix(0, nhA[i+1], c)
 			for (j in (cnhA[i]+1):cnhA[i+1]){
 
-				if (!is.null(dim(drop(pi_A))))
-					YcA[k,] <- PML(ysA[-j,], ysB, pi_A[-j,-j], pi_B, domains_A[-j], domains_B, N_A, N_B)[[2]][1,]
+				if (!is.null(dim(drop(piA))))
+					YcA[k,] <- PML(ysA[-j,], ysB, piA[-j,-j], piB, domainsA[-j], domainsB, N_A, N_B)[[2]][1,]
 				else
-					YcA[k,] <- PML(ysA[-j,], ysB, pi_A[-j], pi_B, domains_A[-j], domains_B, N_A, N_B)[[2]][1,]
+					YcA[k,] <- PML(ysA[-j,], ysB, piA[-j], piB, domainsA[-j], domainsB, N_A, N_B)[[2]][1,]
 				k <- k + 1
 			}
 
 			YcAMean <- matrix(colMeans(YcA), nhA[i+1], c, byrow = TRUE)
 
-			if (fcpA == TRUE){
-				fA <- nhA[i+1]/NhA[i]
-			}else {
+			if (fcpA)
+				fA <- 1 - mean(pikA[strA == strataA[i]])
+			else
 				fA <- 1
-			}
+			
 			YcstrataA[i,] <- (nhA[i+1] - 1) / nhA[i+1] * fA * colSums((YcA - YcAMean)^2)
 		}
 		vjA <- colSums(YcstrataA)	
@@ -112,27 +119,23 @@ JackPML = function (ysA, ysB, pi_A, pi_B, domains_A, domains_B, N_A, N_B, conf_l
 		if (sdA == "clu"){
 
 			clustersA <- unique(clusA)
-			if (!is.null(dim(drop(pi_A))))
-				probclustersA <- unique(data.frame(diag(pi_A), clusA))[,1]
-			else
-				probclustersA <- unique(data.frame(pi_A, clusA))[,1]
+			probclustersA <- unique(data.frame(pikA, clusA))[,1]
 			nclustersA <- length(clustersA)
-			npsuclustersA <- table(clusA)
-			if (any(npsuclustersA < 3))		
-				stop("Number of units in any cluster from frame A is less than 3. Variance cannot be computed.")
+			if (nclustersA < 3)		
+				stop("Number of clusters in frame A is less than 3. Variance cannot be computed.")
 			
 			YcA <- matrix(0, nclustersA, c)
 
 			for (i in 1:nclustersA){
-				if (!is.null(dim(drop(pi_A))))
-					YcA[i,] <- PML(ysA[clusA %in% clustersA[-clustersA[i]],], ysB, pi_A[clusA %in% clustersA[-clustersA[i]],clusA %in% clustersA[-clustersA[i]]], pi_B, domains_A[clusA %in% clustersA[-clustersA[i]]], domains_B, N_A, N_B)[[2]][1,]
+				if (!is.null(dim(drop(piA))))
+					YcA[i,] <- PML(ysA[clusA %in% clustersA[-clustersA[i]],], ysB, piA[clusA %in% clustersA[-clustersA[i]],clusA %in% clustersA[-clustersA[i]]], piB, domainsA[clusA %in% clustersA[-clustersA[i]]], domainsB, N_A, N_B)[[2]][1,]
 				else
-					YcA[i,] <- PML(ysA[clusA %in% clustersA[-clustersA[i]],], ysB, pi_A[clusA %in% clustersA[-clustersA[i]]], pi_B, domains_A[clusA %in% clustersA[-clustersA[i]]], domains_B, N_A, N_B)[[2]][1,]
+					YcA[i,] <- PML(ysA[clusA %in% clustersA[-clustersA[i]],], ysB, piA[clusA %in% clustersA[-clustersA[i]]], piB, domainsA[clusA %in% clustersA[-clustersA[i]]], domainsB, N_A, N_B)[[2]][1,]
 			}
 
 			YcAMean <- matrix(colMeans(YcA), nclustersA, c, byrow = TRUE)
 
-			if (fcpA == TRUE)
+			if (fcpA)
 				fA <- 1 - mean(probclustersA)
 			else
 				fA <- 1
@@ -152,83 +155,82 @@ JackPML = function (ysA, ysB, pi_A, pi_B, domains_A, domains_B, N_A, N_B, conf_l
 				for (i in 1:nstrataA){
 
 					clustersA <- unique(clusA[strA == strataA[i]])
+					probclustersA <- unique(data.frame(pikA[strA == strataA[i]], clusA[strA == strataA[i]]))[,1]
 					nclustersA <- length(clustersA)
-					clusterpsuA <- table(clusA[strA == strataA[i]])
-					if (any(clusterpsuA < 3))		
-					stop("Number of units in any cluster from frame A is less than 3. Variance cannot be computed.")
+					if (nclustersA < 3)		
+						stop("Number of clusters in any stratum from frame A is less than 3. Variance cannot be computed.")
 					k <- 1
 					YcA <- matrix(0, nclustersA, c)
 					for (j in 1:nclustersA){
 
-						if (!is.null(dim(drop(pi_A))))
-							YcA[k,] <- PML(ysA[clusA %in% clustersA[-clustersA[j]],], ysB, pi_A[clusA %in% clustersA[-clustersA[j]],clusA %in% clustersA[-clustersA[j]]], pi_B, domains_A[clusA %in% clustersA[-clustersA[j]]], domains_B, N_A, N_B)[[2]][1,]
+						if (!is.null(dim(drop(piA))))
+							YcA[k,] <- PML(ysA[clusA %in% clustersA[-clustersA[j]],], ysB, piA[clusA %in% clustersA[-clustersA[j]],clusA %in% clustersA[-clustersA[j]]], piB, domainsA[clusA %in% clustersA[-clustersA[j]]], domainsB, N_A, N_B)[[2]][1,]
 						else
-							YcA[k,] <- PML(ysA[clusA %in% clustersA[-clustersA[j]],], ysB, pi_A[clusA %in% clustersA[-clustersA[j]]], pi_B, domains_A[clusA %in% clustersA[-clustersA[j]]], domains_B, N_A, N_B)[[2]][1,]
+							YcA[k,] <- PML(ysA[clusA %in% clustersA[-clustersA[j]],], ysB, piA[clusA %in% clustersA[-clustersA[j]]], piB, domainsA[clusA %in% clustersA[-clustersA[j]]], domainsB, N_A, N_B)[[2]][1,]
 						k <- k + 1
 					}
 
 					YcAMean <- matrix(colMeans(YcA), nclustersA, c, byrow = TRUE)
 
-					if (fcpA == TRUE){
-						fA <- nclustersA/NclushA[i]
-					}else {
+					if (fcpA)
+						fA <- 1 - mean(probclustersA)
+					else
 						fA <- 1
-					}
+					
 					YcstrataA[i,] <- (nclustersA - 1) / nclustersA * fA * colSums((YcA - YcAMean)^2)
 				}
 				vjA <- colSums(YcstrataA)
 			}else{
-				n_A <- nrow(ysA)
-				YcA <- matrix(0, n_A, c)
+				nA <- nrow(ysA)
+				YcA <- matrix(0, nA, c)
 		
-				for (i in 1:n_A){
-					if (!is.null(dim(drop(pi_A))))
-						YcA[i,] <- PML(ysA[-i,], ysB, pi_A[-i,-i], pi_B, domains_A[-i], domains_B, N_A, N_B)[[2]][1,]
+				for (i in 1:nA){
+					if (!is.null(dim(drop(piA))))
+						YcA[i,] <- PML(ysA[-i,], ysB, piA[-i,-i], piB, domainsA[-i], domainsB, N_A, N_B)[[2]][1,]
 					else
-						YcA[i,] <- PML(ysA[-i,], ysB, pi_A[-i], pi_B, domains_A[-i], domains_B, N_A, N_B)[[2]][1,]
+						YcA[i,] <- PML(ysA[-i,], ysB, piA[-i], piB, domainsA[-i], domainsB, N_A, N_B)[[2]][1,]
 				}
 
-				YcAMean <- matrix(colMeans(YcA), n_A, c, byrow = TRUE)
+				YcAMean <- matrix(colMeans(YcA), nA, c, byrow = TRUE)
 	
-				if (fcpA == TRUE)
-					if (!is.null(dim(drop(pi_A))))
-						fA <- 1 - mean(diag(pi_A))
-					else
-						fA <- 1 - mean(pi_A)
+				if (fcpA)
+					fA <- 1 - mean(pikA)
 				else
 					fA <- 1
 
-				vjA <- ((n_A - 1) / n_A) * fA * colSums ((YcA - YcAMean)^2)
+				vjA <- ((nA - 1) / nA) * fA * colSums ((YcA - YcAMean)^2)
 			}	
 		}
 	}
 	if (sdB == "str"){
 
+		strataB <- unique(strB)
 		nhB <- table(strB)
-		strataB <- length(nhB)
-		YcstrataB <- matrix(0, strataB, c)
+		nstrataB <- length(nhB)
+		YcstrataB <- matrix(0, nstrataB, c)
 		nhB <- c(0,nhB)
 		cnhB <- cumsum(nhB)
 
-		for (i in 1:strataB){
+		for (i in 1:nstrataB){
 
 			k <- 1
 			YcB <- matrix(0, nhB[i+1], c)
 			for (j in (cnhB[i]+1):cnhB[i+1]){
 
-				if (!is.null(dim(drop(pi_B))))
-					YcB[k,] <- PML(ysA, ysB[-j,], pi_A, pi_B[-j,-j], domains_A, domains_B[-j], N_A, N_B)[[2]][1,]
+				if (!is.null(dim(drop(piB))))
+					YcB[k,] <- PML(ysA, ysB[-j,], piA, piB[-j,-j], domainsA, domainsB[-j], N_A, N_B)[[2]][1,]
 				else
-					YcB[k,] <- PML(ysA, ysB[-j,], pi_A, pi_B[-j], domains_A, domains_B[-j], N_A, N_B)[[2]][1,]
+					YcB[k,] <- PML(ysA, ysB[-j,], piA, piB[-j], domainsA, domainsB[-j], N_A, N_B)[[2]][1,]
 				k <- k + 1
 			}
 
 			YcBMean <- matrix(colMeans(YcB), nhB[i+1], c, byrow = TRUE)
 
-			if (fcpB == TRUE)
-				fB <- nhB[i+1]/NhB[i]
+			if (fcpB)
+				fB <- 1 - mean(pikB[strB == strataB[i]])
 			else
 				fB <- 1
+
 			YcstrataB[i,] <- (nhB[i+1] - 1) / nhB[i+1] * fB * colSums((YcB - YcBMean)^2)
 		}
 		vjB <- colSums(YcstrataB)	
@@ -238,27 +240,23 @@ JackPML = function (ysA, ysB, pi_A, pi_B, domains_A, domains_B, N_A, N_B, conf_l
 		if (sdB == "clu"){
 
 			clustersB <- unique(clusB)
-			if (!is.null(dim(drop(pi_B))))
-				probclustersB <- unique(data.frame(diag(pi_B), clusB))[,1]
-			else
-				probclustersB <- unique(data.frame(pi_B, clusB))[,1]
+			probclustersB <- unique(data.frame(pikB, clusB))[,1]
 			nclustersB <- length(clustersB)
-			npsuclustersB <- table(clusB)
-			if (any(npsuclustersB < 3))		
-				stop("Number of units in any cluster from frame B is less than 3. Variance cannot be computed.")		
+			if (nclustersB < 3)		
+				stop("Number of clusters in frame B is less than 3. Variance cannot be computed.")		
 
 			YcB <- matrix(0, nclustersB, c)
 
 			for (i in 1:nclustersB){
-				if (!is.null(dim(drop(pi_B))))
-					YcB[i,] <- PML(ysA, ysB[clusB %in% clustersB[-clustersB[i]],], pi_A, pi_B[clusB %in% clustersB[-clustersB[i]],clusB %in% clustersB[-clustersB[i]]], domains_A, domains_B[clusB %in% clustersB[-clustersB[i]]], N_A, N_B)[[2]][1,]
+				if (!is.null(dim(drop(piB))))
+					YcB[i,] <- PML(ysA, ysB[clusB %in% clustersB[-clustersB[i]],], piA, piB[clusB %in% clustersB[-clustersB[i]],clusB %in% clustersB[-clustersB[i]]], domainsA, domainsB[clusB %in% clustersB[-clustersB[i]]], N_A, N_B)[[2]][1,]
 				else
-					YcB[i,] <- PML(ysA, ysB[clusB %in% clustersB[-clustersB[i]],], pi_A, pi_B[clusB %in% clustersB[-clustersB[i]]], domains_A, domains_B[clusB %in% clustersB[-clustersB[i]]], N_A, N_B)[[2]][1,]
+					YcB[i,] <- PML(ysA, ysB[clusB %in% clustersB[-clustersB[i]],], piA, piB[clusB %in% clustersB[-clustersB[i]]], domainsA, domainsB[clusB %in% clustersB[-clustersB[i]]], N_A, N_B)[[2]][1,]
 			}
 
 			YcBMean <- matrix(colMeans(YcB), nclustersB, c, byrow = TRUE)
 
-			if (fcpB == TRUE)
+			if (fcpB)
 				fB <- 1 - mean(probclustersB)
 			else
 				fB <- 1
@@ -279,54 +277,51 @@ JackPML = function (ysA, ysB, pi_A, pi_B, domains_A, domains_B, N_A, N_B, conf_l
 				for (i in 1:nstrataB){
 
 					clustersB <- unique(clusB[strB == strataB[i]])
+					probclustersB <- unique(data.frame(pikB[strB == strataB[i]], clusB[strB == strataB[i]]))[,1]					
 					nclustersB <- length(clustersB)
-					clusterpsuB <- table(clusB[strB == strataB[i]])
-					if (any(clusterpsuB < 3))		
-					stop("Number of units in any cluster from frame B is less than 3. Variance cannot be computed.")
+					if (nclustersB < 3)		
+						stop("Number of clusters in any stratum from frame B is less than 3. Variance cannot be computed.")
 					k <- 1
 					YcB <- matrix(0, nclustersB, c)
 					for (j in 1:nclustersB){
 
-						if (!is.null(dim(drop(pi_B))))
-							YcB[k,] <- PML(ysA, ysB[clusB %in% clustersB[-clustersB[j]],], pi_A, pi_B[clusB %in% clustersB[-clustersB[j]],clusB %in% clustersB[-clustersB[j]]], domains_A, domains_B[clusB %in% clustersB[-clustersB[j]]], N_A, N_B)[[2]][1,]
+						if (!is.null(dim(drop(piB))))
+							YcB[k,] <- PML(ysA, ysB[clusB %in% clustersB[-clustersB[j]],], piA, piB[clusB %in% clustersB[-clustersB[j]],clusB %in% clustersB[-clustersB[j]]], domainsA, domainsB[clusB %in% clustersB[-clustersB[j]]], N_A, N_B)[[2]][1,]
 						else
-							YcB[k,] <- PML(ysA, ysB[clusB %in% clustersB[-clustersB[j]],], pi_A, pi_B[clusB %in% clustersB[-clustersB[j]]], domains_A, domains_B[clusB %in% clustersB[-clustersB[j]]], N_A, N_B)[[2]][1,]
+							YcB[k,] <- PML(ysA, ysB[clusB %in% clustersB[-clustersB[j]],], piA, piB[clusB %in% clustersB[-clustersB[j]]], domainsA, domainsB[clusB %in% clustersB[-clustersB[j]]], N_A, N_B)[[2]][1,]
 						k <- k + 1
 					}
 
 					YcBMean <- matrix(colMeans(YcB), nclustersB, c, byrow = TRUE)
 
-					if (fcpB == TRUE){
-						fB <- nclustersB/NclushB[i]
-					}else {
+					if (fcpB)
+						fB <- 1 - mean(probclustersB)
+					else
 						fB <- 1
-					}
+					
 					YcstrataB[i,] <- (nclustersB - 1) / nclustersB * fB * colSums((YcB - YcBMean)^2)
 				}
 				vjB <- colSums(YcstrataB)
 			}else{
-				n_B <- nrow(ysB)
-				YcB <- matrix(0, n_B, c)
+				nB <- nrow(ysB)
+				YcB <- matrix(0, nB, c)
 
-				for (i in 1:n_B){
+				for (i in 1:nB){
 
-					if (!is.null(dim(drop(pi_B))))
-						YcB[i,] <- PML(ysA, ysB[-i,], pi_A, pi_B[-i,-i], domains_A, domains_B[-i], N_A, N_B)[[2]][1,]
+					if (!is.null(dim(drop(piB))))
+						YcB[i,] <- PML(ysA, ysB[-i,], piA, piB[-i,-i], domainsA, domainsB[-i], N_A, N_B)[[2]][1,]
 					else
-						YcB[i,] <- PML(ysA, ysB[-i,], pi_A, pi_B[-i], domains_A, domains_B[-i], N_A, N_B)[[2]][1,]
+						YcB[i,] <- PML(ysA, ysB[-i,], piA, piB[-i], domainsA, domainsB[-i], N_A, N_B)[[2]][1,]
 				}
 
-				YcBMean <- matrix(colMeans(YcB), n_B, c, byrow = TRUE)
+				YcBMean <- matrix(colMeans(YcB), nB, c, byrow = TRUE)
 
-				if (fcpB == TRUE)
-					if (!is.null(dim(drop(pi_B))))
-						fB <- 1-mean(diag(pi_B))
-					else
-						fB <- 1-mean(pi_B)
+				if (fcpB)
+					fB <- 1 - mean(pikB)
 				else
 					fB <- 1
 
-				vjB <- ((n_B - 1) / n_B) * fB * colSums((YcB - YcBMean)^2)
+				vjB <- ((nB - 1) / nB) * fB * colSums((YcB - YcBMean)^2)
 			}
 		}
 	}
