@@ -48,31 +48,27 @@
 #'  \emph{Calibration estimators in survey sampling.}
 #'  Journal of the American Statistical Association, 87, 376 - 382
 #' @examples
-#' data(HouseholdsA)
-#' dataA <- attach(HouseholdsA)
-#' detach(HouseholdsA)
-#' data(HouseholdsB)
-#' dataB <- attach(HouseholdsB)
-#' detach(HouseholdsB)
+#' data(DatA)
+#' data(DatB)
 #' data(PiklA)
 #' data(PiklB)
 #' 
 #' #Let calculate g-weights for the dual frame calibration estimator for variable Feeding, 
 #' #without considering any auxiliary information
-#' WeightsCalDF(dataA$Feeding, dataB$Feeding, PiklA, PiklB, dataA$Domain, dataB$Domain)
+#' WeightsCalDF(DatA$Feed, DatB$Feed, PiklA, PiklB, DatA$Domain, DatB$Domain)
 #' 
 #' #Now, let calculate g-weights for the dual frame calibration estimator for variable Clothing 
 #' #when the frame sizes and the overlap domain size are known
-#' WeightsCalDF(dataA$Clothing, dataB$Clothing, PiklA, PiklB, dataA$Domain, dataB$Domain, 
+#' WeightsCalDF(DatA$Clo, DatB$Clo, PiklA, PiklB, DatA$Domain, DatB$Domain, 
 #' N_A = 1735, N_B = 1191, N_ab = 601)
 #' 
 #' #Finally, let calculate g-weights for the dual frame calibration estimator
 #' #for variable Feeding, considering Income as auxiliary variable in frame A
 #' #and Metres2 as auxiliary variable in frame B and with frame sizes and overlap 
 #' #domain size known.
-#' WeightsCalDF(dataA$Feeding, dataB$Feeding, PiklA, PiklB, dataA$Domain, dataB$Domain, 
-#' N_A = 1735, N_B =  1191, N_ab = 601, xsAFrameA = dataA$Income, xsBFrameA = dataB$Income, 
-#' xsAFrameB = dataA$Metres2, xsBFrameB = dataB$Metres2, XA = 4300260, XB = 176553)
+#' WeightsCalDF(DatA$Feed, DatB$Feed, PiklA, PiklB, DatA$Domain, DatB$Domain, 
+#' N_A = 1735, N_B =  1191, N_ab = 601, xsAFrameA = DatA$Inc, xsBFrameA = DatB$Inc, 
+#' xsAFrameB = DatA$M2, xsBFrameB = DatB$M2, XA = 4300260, XB = 176553)
 #' @export
 WeightsCalDF = function (ysA, ysB, pi_A, pi_B, domains_A, domains_B, N_A = NULL, N_B = NULL, N_ab = NULL, xsAFrameA = NULL, xsBFrameA = NULL, xsAFrameB = NULL, xsBFrameB = NULL, xsT = NULL, XA = NULL, XB = NULL, X = NULL, met = "linear") {
 
@@ -102,9 +98,9 @@ WeightsCalDF = function (ysA, ysB, pi_A, pi_B, domains_A, domains_B, N_A = NULL,
 		stop("Domains from frame A are not correct.")
 	if (length(which(domains_B == "b")) + length(which(domains_B == "ba")) != length(domains_B))
 		stop("Domains from frame B are not correct.")
-	if ((is.null (N_A) == "TRUE" & is.null (N_B) == "FALSE") | (is.null (N_A) == "FALSE" & is.null (N_B) == "TRUE"))
+	if ((is.null (N_A) & !is.null (N_B)) | (!is.null (N_A) & is.null (N_B)))
 		stop("Only one value has been indicated for N_A and N_B. This is not valid. Both or none should be indicated.")
-	if (is.null (N_ab) == "FALSE" & (is.null (N_A) == "TRUE" | is.null (N_B) == "TRUE"))
+	if (!is.null (N_ab) & (is.null (N_A) | is.null (N_B)))
 		stop("A value for N_ab has been provided, but values for N_A or N_B are missing. This is not a possible option.")
 	if ((is.null (xsAFrameA) & !is.null (xsBFrameA)) | (!is.null (xsAFrameA) & is.null (xsBFrameA)))
 		stop("Auxiliary information from Frame A is available only in one sample. This is not a possible option.")
