@@ -113,4 +113,15 @@ PELConfInt = function (a, ys, ds, YEL, nss, ps)
  	cat("\n",attr(object, "attributesDF")[1]*100,"% Confidence Intervals:\n")
   	print(object$ConfInt)
   }
-}
\ No newline at end of file
+}
+
+`print.EstimatorMDF`=function(x, ...){
+  if (is.null(attr(x, "attributesMDF")[1])){
+  	cat("\nEstimation:\n")
+  	print(x$Est)
+  }
+  else {
+	cat("\nEstimation and ",attr(x, "attributesMDF")[1]*100,"% Confidence Intervals:\n")
+  	print(x$ConfInt)
+  }
+}
